@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -123,8 +123,12 @@ class IconEditorWindow(E5MainWindow):
         """
         filters = {
             'bmp': self.tr("Windows Bitmap File (*.bmp)"),
+            'cur': self.tr("Windows Cursor File (*.cur)"),
+            'dds': self.tr("DirectDraw-Surface File (*.dds)"),
             'gif': self.tr("Graphic Interchange Format File (*.gif)"),
+            'icns': self.tr("Apple Icon File (*.icns)"),
             'ico': self.tr("Windows Icon File (*.ico)"),
+            'jp2': self.tr("JPEG2000 File (*.jp2)"),
             'jpg': self.tr("JPEG File (*.jpg)"),
             'jpeg': self.tr("JPEG File (*.jpeg)"),
             'mng': self.tr("Multiple-Image Network Graphics File (*.mng)"),
@@ -141,6 +145,7 @@ class IconEditorWindow(E5MainWindow):
             'tif': self.tr("TIFF File (*.tif)"),
             'tiff': self.tr("TIFF File (*.tiff)"),
             'wbmp': self.tr("WAP Bitmap File (*.wbmp)"),
+            'webp': self.tr("WebP Image File (*.webp)"),
             'xbm': self.tr("X11 Bitmap File (*.xbm)"),
             'xpm': self.tr("X11 Pixmap File (*.xpm)"),
         }
