@@ -237,6 +237,9 @@ _messages = {
     "E721": QCoreApplication.translate(
         "pycodestyle",
         "do not compare types, use 'isinstance()'"),
+    "E722": QCoreApplication.translate(
+        "pycodestyle",
+        "do not use bare except"),
     "E731": QCoreApplication.translate(
         "pycodestyle",
         "do not assign a lambda expression, use a def"),
