@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2014 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2014 - 2017 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -164,13 +164,15 @@ class PreviewerHTML(QWidget):
                 extension = ""
             if extension in \
                 Preferences.getEditor("PreviewHtmlFileNameExtensions") or \
-               editor.getLanguage() == "HTML":
+                    editor.getLanguage() == "HTML":
                 language = "HTML"
             elif extension in \
-                    Preferences.getEditor("PreviewMarkdownFileNameExtensions"):
+                Preferences.getEditor("PreviewMarkdownFileNameExtensions") or \
+                    editor.getLanguage().lower() == "markdown":
                 language = "Markdown"
             elif extension in \
-                    Preferences.getEditor("PreviewRestFileNameExtensions"):
+                Preferences.getEditor("PreviewRestFileNameExtensions") or \
+                    editor.getLanguage().lower() == "restructuredtext":
                 language = "ReST"
             else:
                 self.__setHtml(fn, self.tr(
@@ -186,10 +188,11 @@ class PreviewerHTML(QWidget):
             else:
                 rootPath = ""
             
-            self.__processingThread.process(
-                fn, language, editor.text(),
-                self.ssiCheckBox.isChecked(), rootPath,
-                Preferences.getEditor("PreviewRestUseSphinx"))
+            if bool(editor.text()):
+                self.__processingThread.process(
+                    fn, language, editor.text(),
+                    self.ssiCheckBox.isChecked(), rootPath,
+                    Preferences.getEditor("PreviewRestUseSphinx"))
 
     def __setHtml(self, filePath, html):
         """
@@ -208,6 +211,8 @@ class PreviewerHTML(QWidget):
         else:
             self.previewView.page().loadFinished.connect(
                 self.__restoreScrollBarPositions)
+            if not filePath:
+                filePath = "/"
         self.previewView.setHtml(html, baseUrl=QUrl.fromLocalFile(filePath))
         if self.__previewedEditor:
             self.__previewedEditor.setFocus()
@@ -338,11 +343,6 @@ class PreviewProcessingThread(QThread):
     """
     htmlReady = pyqtSignal(str, str)
     
-    DefaultStaticPath = os.path.join(
-        os.path.abspath(os.path.dirname(__file__)), 'sphinx_default')
-    StaticRegexp = re.compile(r'(src|href)=["\']_static([\s\w/\.]+?)["\']',
-                              re.IGNORECASE)
-    
     def __init__(self, parent=None):
         """
         Constructor
@@ -537,13 +537,6 @@ class PreviewProcessingThread(QThread):
             fh.close()
         finally:
             shutil.rmtree(tempDir)
-
-        # Replace the "_static/..." references inserted by Sphinx with absolute
-        # links to the specified DefaultStaticPath replacement.
-        def replace(m):
-            return '{0}="file://{1}{2}"'.format(
-                m.group(1), self.DefaultStaticPath, m.group(2))
-        html = re.sub(self.StaticRegexp, replace, html)
         
         return html
     
@@ -591,7 +584,8 @@ class PreviewProcessingThread(QThread):
         except ImportError:
             return self.tr(
                 """<p>Markdown preview requires the <b>python-markdown</b> """
-                """package.<br/>Install it with your package manager or see """
+                """package.<br/>Install it with your package manager,"""
+                """ 'pip install docutils' or see """
                 """<a href="http://pythonhosted.org/Markdown/install.html">"""
                 """installation instructions.</a></p>""")
         
